==> spread-5.6.1.59-py3-none-any.whl: spread_core/tests/projector/project_init_template.py <==
from spread_core.mqtt.project import Header, Hardware, Provider, Equipment, Location, Subginery,\
                                     Cycle, CycleTrigger, Preset
from spread_lom.profiles import DimmingProfile
from spread_core.bam.engineries.lighting_area import ButtonPreset

"""
    ctp             # {entity: entity_data}
    project         # ctp + storage
    SERVERS         # [server_id]
    MANAGERS        # {'manager_id': 'manager_type'}
    PROVIDERS       # {'provider_id': 'provider_type'}
    ENGINERIES      # {'enginery_id': 'enginery_type'}
    LOCATIONS       # [location_id]
    CYCLES          # [cycle_id]
"""

id = 1104
SERVERS = [1333]
MANAGERS = {4770: "Dali"}
PROVIDERS = {178975: "DaliDimmer"}
ENGINERIES = {171102: "DimmingLight"}
LOCATIONS = [17099]
CYCLES = [1]
ctp = {
    Header(id, "Project"): {
        "name": "\u042f\u0440\u0422\u0435\u0441\u0442\u0422\u0435\u0441\u0442 \u043f\u0443\u0441\u0442\u043e\u04395",
        "cloudCode": "385636613588",
        "rootLocationID": 17099,
        "pin": "1234",
        "title": "\u042f\u0440\u0422\u0435\u0441\u0442 \u043f\u0443\u0441\u0442\u043e\u0439 - \u0442\u0430\u0439\u0442\u043b"
    },
    Header(id, "Firmware"): {
        "type": "Commercial",
        "key": "e9b6f265-e595-4cfc-ba93-be96161a1447",
        "build": 17,
        "builder": "(alpha)4.8.0",
        "date": "2022-11-02T13:29:00.614502",
        "user": "Elena Dobryakova"
    },
    Hardware(id, "Dali", 4770): {
        "key": "1d00b5c1-1b01-4b12-967e-b0c4aaf995fc",
        "attributes": {
            "pollRate": 1000,
            "bus": "Rapida/0/Dali/1/1"
        },
        "serverID": 1333
    },
    Provider(id, "Dali", 4770, "DaliDimmer", 178975): {
        "key": "e6d248c7-49cf-4ee6-ab59-379faf1c3107",
        "attributes": {
            "group": 1,
            "device": 0,
            "binding": "Device"
        }
    },
    Equipment(id, "DimmingLight", 171102): {
        "key": "43a42e7c-b063-48ef-a5d1-cb84fc9d058b",
        "name": "Entrance",
        "attributes": {
            "power": 0,
            "positionCount": 101,
            "lowerLimit": 0,
            "upperLimit": 100
        },
        "label": "2",
        "recipe": {
            "type": "Simple",
            "ingredients": [
                {
                    "index": 0,
                    "type": "Solid",
                    "id": 178975
                }
            ]
        }
    },
    Location(id, 17099): {
        "key": "dbaee592-5095-4293-90d9-c5163ccb2c74",
        "name": "SCC",
        "arrangements": [
            {
                "position": {
                    "x": 255.9055,
                    "z": 603.025635,
                    "y": -345.329651
                },
                "center": {
                    "x": 255.9055,
                    "z": 32.6959763,
                    "y": 225.0
                },
                "widget": [],
                "models": [
                    {
                        "position": {
                            "x": 0.0,
                            "z": 0.0,
                            "y": 0.0
                        },
                        "visibility": True,
                        "id": 2494
                    }
                ],
                "title": "Title"
            },
            {
                "position": {
                    "x": 518.352844,
                    "z": 757.7658,
                    "y": 338.624084
                },
                "center": {
                    "x": 521.4885,
                    "z": 92.77143,
                    "y": 231.407974
                },
                "widget": [],
                "models": [
                    {
                        "position": {
                            "x": 0.0,
                            "z": 0.0,
                            "y": 0.0
                        },
                        "visibility": True,
                        "id": 2494
                    }
                ],
                "title": "Title"
            }
        ],
        "models": [
            {
                "transitions": [],
                "id": 2494,
                "controls": [
                    {
                        "clickable": True,
                        "engineryID": 171102
                    }
                ]
            }
        ],
        "navigations": [
            17099
        ]
    },
    Subginery(id, 17099, "Lighting", 171132): {
        "key": "7f067fa0-4fe2-4361-bfab-8b306a629520",
        "engineries": [
            171102
        ]
    }
}

==> spread-5.8.1.80-py3-none-any.whl: spread_core/tests/projector/project_init_template.py <==
from spread_core.mqtt.project import Header, Hardware, Provider, Equipment, Location, Subginery,\
                                     Cycle, CycleTrigger, Preset
from spread_lom.profiles import DimmingProfile
from spread_core.bam.engineries.lighting_area import ButtonPreset

"""
    ctp             # {entity: entity_data}
    project         # ctp + storage
    SERVERS         # [server_id]
    MANAGERS        # {'manager_id': 'manager_type'}
    PROVIDERS       # {'provider_id': 'provider_type'}
    ENGINERIES      # {'enginery_id': 'enginery_type'}
    LOCATIONS       # [location_id]
    CYCLES          # [cycle_id]
"""

id = 1104
SERVERS = [1333]
MANAGERS = {4770: "Dali"}
PROVIDERS = {178975: "DaliDimmer"}
ENGINERIES = {171102: "DimmingLight", 395439: "LightingArea"}
LOCATIONS = [17099]
CYCLES = [1]
ctp = {
    Header(id, "Project"): {
        "name": "\u042f\u0440\u0422\u0435\u0441\u0442\u0422\u0435\u0441\u0442 \u043f\u0443\u0441\u0442\u043e\u04395",
        "cloudCode": "385636613588",
        "rootLocationID": 17099,
        "pin": "1234",
        "title": "\u042f\u0440\u0422\u0435\u0441\u0442 \u043f\u0443\u0441\u0442\u043e\u0439 - \u0442\u0430\u0439\u0442\u043b"
    },
    Header(id, "Firmware"): {
        "type": "Commercial",
        "key": "e9b6f265-e595-4cfc-ba93-be96161a1447",
        "build": 17,
        "builder": "(alpha)4.8.0",
        "date": "2022-11-02T13:29:00.614502",
        "user": "Elena Dobryakova"
    },
    Hardware(id, "Dali", 4770): {
        "key": "1d00b5c1-1b01-4b12-967e-b0c4aaf995fc",
        "attributes": {
            "pollRate": 1000,
            "bus": "Rapida/0/Dali/1/1"
        },
        "serverID": 1333
    },
    Provider(id, "Dali", 4770, "DaliDimmer", 178975): {
        "key": "e6d248c7-49cf-4ee6-ab59-379faf1c3107",
        "attributes": {
            "group": 1,
            "device": 0,
            "binding": "Device"
        }
    },
    Equipment(id, "DimmingLight", 171102): {
        "key": "43a42e7c-b063-48ef-a5d1-cb84fc9d058b",
        "name": "Entrance",
        "attributes": {
            "power": 0,
            "positionCount": 101,
            "lowerLimit": 0,
            "upperLimit": 100
        },
        "label": "2",
        "recipe": {
            "type": "Simple",
            "ingredients": [
                {
                    "index": 0,
                    "type": "Solid",
                    "id": 178975
                }
            ]
        }
    },
Equipment(id, "LightingArea", 395439): {
        "key": "630a2882-052b-4129-9d27-54cd159c5870",
        "name": "TestArea",
        "label": "3",
        "recipe": {
            "type": "Piecemeal",
            "ingredients": [
                 {
                  "index": 0,
                  "type": "Actuation",
                  "id": 178975
                 }
            ]
        }
    },
    Location(id, 17099): {
        "key": "dbaee592-5095-4293-90d9-c5163ccb2c74",
        "name": "SCC",
        "arrangements": [
            {
                "position": {
                    "x": 255.9055,
                    "z": 603.025635,
                    "y": -345.329651
                },
                "center": {
                    "x": 255.9055,
                    "z": 32.6959763,
                    "y": 225.0
                },
                "widget": [],
                "models": [
                    {
                        "position": {
                            "x": 0.0,
                            "z": 0.0,
                            "y": 0.0
                        },
                        "visibility": True,
                        "id": 2494
                    }
                ],
                "title": "Title"
            },
            {
                "position": {
                    "x": 518.352844,
                    "z": 757.7658,
                    "y": 338.624084
                },
                "center": {
                    "x": 521.4885,
                    "z": 92.77143,
                    "y": 231.407974
                },
                "widget": [],
                "models": [
                    {
                        "position": {
                            "x": 0.0,
                            "z": 0.0,
                            "y": 0.0
                        },
                        "visibility": True,
                        "id": 2494
                    }
                ],
                "title": "Title"
            }
        ],
        "models": [
            {
                "transitions": [],
                "id": 2494,
                "controls": [
                    {
                        "clickable": True,
                        "engineryID": 171102
                    }
                ]
            }
        ],
        "navigations": [
            17099
        ]
    },
    Subginery(id, 17099, "Lighting", 171132): {
        "key": "7f067fa0-4fe2-4361-bfab-8b306a629520",
        "engineries": [
            171102
        ]
    }
}
